package
Version:
v1.1.8
Opens a new window with list of versions in this module.
Published: Jan 10, 2025
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Markdown struct {
Content string `json:"content"`
}
type Msg struct {
MsgType string `json:"msgtype"`
Markdown *Markdown `json:"markdown,omitempty"`
Text *Text `json:"text,omitempty"`
}
type Text struct {
Content string `json:"content"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.